@@ -340,7 +340,7 @@ int process_cgivars(void) {
 	variables = getcgivars();
 	to_expand[0] = '\0';
 
-	for(x = 0; variables[x] != NULL; x++) {
+	for(x = 0; variables[x]; x++) {
 
 		/* do some basic length checking on the variable identifier to prevent buffer overflows */
 		if(strlen(variables[x]) >= MAX_INPUT_BUFFER - 1) {
